@@ -28,6 +28,9 @@
 // Global includes
 #include <QtGui/QDialog>
 
+// Forward declarations
+class QFormLayout;
+
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -49,6 +52,9 @@ public:
   void setPassword(const QString& password);
   QString password() const;
 
+  /// Return the form layout
+  QFormLayout* formLayout() const;
+
 private:
   class Ui_AccountSettingsDialog *ui;
 };
