@@ -207,10 +207,6 @@ public:
         << ProviderInfo(tr("3 Ireland"), "9bd09e1e-7e9e-4666-b516-6bfd3a23972c", QIcon(":/providers/webtexter/three_ireland.png"), QLocale::Ireland)
         << ProviderInfo(tr("Meteor Ireland"), "1839f8b7-3b89-4033-9b23-314fb9b5fc44", QIcon(":/providers/webtexter/meteor_ireland.png"), QLocale::Ireland)
         << ProviderInfo(tr("Blueface Ireland"), "c3bfe4b8-2ea5-4e4a-a9de-4eeb76b72f60", QIcon(":/providers/webtexter/blueface_ireland.png"), QLocale::Ireland)
-        << ProviderInfo(tr("VoipCheap.com"), "57c898fd-d071-4eaa-ad84-45ad8eb7389f", QIcon(":/providers/webtexter/voipcheap.com.png"), QLocale::AnyCountry)
-        << ProviderInfo(tr("SMSdiscount.com"), "8776a080-d81a-40f8-b381-8843b917f5c3", QIcon(":/providers/webtexter/smsdiscount.com.png"), QLocale::AnyCountry)
-        << ProviderInfo(tr("Lowratevoip.com"), "99e3f01f-5ddd-4b3a-9e3b-c26b588e77f9", QIcon(), QLocale::AnyCountry)
-        << ProviderInfo(tr("Other Betamax"), "32d6fb08-5cc3-45f8-87de-5eea303b7b98", QIcon(), QLocale::AnyCountry)
         << ProviderInfo(tr("WebSMS.ru"), "7d0f8d29-efa5-4ced-a0c1-a4a3b11069ee", QIcon(":/providers/webtexter/websms.ru.png"), QLocale::RussianFederation)
         << ProviderInfo(tr("Exetel Australia"), "ceb3cb26-9a73-48da-ab07-5f642d2b8c16", QIcon(), QLocale::Australia);
   }
@@ -235,14 +231,6 @@ public:
       provider = METEOR;
     else if ( name == "c3bfe4b8-2ea5-4e4a-a9de-4eeb76b72f60" )
       provider = BLUEFACE;
-    else if ( name == "57c898fd-d071-4eaa-ad84-45ad8eb7389f" )
-      provider = VOIPCHEAP;
-    else if ( name == "8776a080-d81a-40f8-b381-8843b917f5c3" )
-      provider = SMSDISCOUNT;
-    else if ( name == "99e3f01f-5ddd-4b3a-9e3b-c26b588e77f9" )
-      provider = LOWRATEVOIP;
-    else if ( name == "32d6fb08-5cc3-45f8-87de-5eea303b7b98" )
-      provider = OTHER_BETAMAX;
     else if ( name == "7d0f8d29-efa5-4ced-a0c1-a4a3b11069ee" )
       provider = WEBSMSRU;
     else if ( name == "ceb3cb26-9a73-48da-ab07-5f642d2b8c16" )
